@@ -1,12 +1,14 @@
-mod file {
+mod blob {
     use std::sync::Arc;
+    use std::time::Duration;
 
+    use crate::reporter::SimpleReporterFactory;
     use crate::{config::Config, test_utils::*, Condow};
 
     use crate::test_utils::create_test_data;
 
     #[tokio::test]
-    async fn download_blob() {
+    async fn download_complete_blob_with_reporter() {
         let buffer_size = 10;
 
         let data = Arc::new(create_test_data());
@@ -26,12 +28,13 @@ mod file {
                         .buffers_full_delay_ms(0)
                         .part_size_bytes(part_size)
                         .max_concurrency(n_concurrency);
-                    let condow = Condow::new(client.clone(), config).unwrap();
+                    let condow =
+                        Condow::new_with_reporting(client.clone(), config, SimpleReporterFactory)
+                            .unwrap();
 
-                    let result_stream = condow
-                        .download_chunks_internal((), .., Default::default())
-                        .await
-                        .unwrap();
+                    let downloader = condow.downloader();
+
+                    let result_stream = downloader.download_rep((), ..).await.unwrap();
 
                     let result = result_stream.into_stream().into_vec().await.unwrap();
 
@@ -40,12 +43,49 @@ mod file {
             }
         }
     }
+
+    #[tokio::test]
+    async fn check_simple_reporter() {
+        let buffer_size = 10;
+
+        let data = Arc::new(create_test_data());
+
+        for chunk_size in [1, 3, 5] {
+            let client = TestCondowClient {
+                data: Arc::clone(&data),
+                max_jitter_ms: 0,
+                include_size_hint: true,
+                max_chunk_size: chunk_size,
+            };
+
+            for part_size in [1usize, 3, 50, 1_000] {
+                for n_concurrency in [1usize, 10] {
+                    let config = Config::default()
+                        .buffer_size(buffer_size)
+                        .buffers_full_delay_ms(0)
+                        .part_size_bytes(part_size)
+                        .max_concurrency(n_concurrency);
+                    let condow =
+                        Condow::new_with_reporting(client.clone(), config, SimpleReporterFactory)
+                            .unwrap();
+
+                    let downloader = condow.downloader();
+
+                    let result_stream = downloader.download_rep((), ..).await.unwrap();
+
+                    let report = result_stream.reporter.report();
+                    assert!(report.download_time > Duration::ZERO);
+                }
+            }
+        }
+    }
 }
 
 mod range {
     mod open {
         use std::sync::Arc;
 
+        use crate::reporter::SimpleReporter;
         use crate::{config::Config, test_utils::create_test_data, test_utils::*, Condow};
 
         #[tokio::test]
@@ -79,6 +119,7 @@ mod range {
                                     (),
                                     range.clone(),
                                     crate::GetSizeMode::Always,
+                                    SimpleReporter::default(),
                                 )
                                 .await
                                 .unwrap();
@@ -124,6 +165,7 @@ mod range {
                                     (),
                                     range.clone(),
                                     crate::GetSizeMode::Required,
+                                    SimpleReporter::default(),
                                 )
                                 .await
                                 .unwrap();
@@ -142,6 +184,7 @@ mod range {
     mod closed {
         use std::sync::Arc;
 
+        use crate::reporter::SimpleReporter;
         use crate::{config::Config, test_utils::create_test_data, test_utils::*, Condow};
 
         #[tokio::test]
@@ -176,6 +219,7 @@ mod range {
                                     (),
                                     range.clone(),
                                     crate::GetSizeMode::Default,
+                                    SimpleReporter::default(),
                                 )
                                 .await
                                 .unwrap();
@@ -221,6 +265,7 @@ mod range {
                                     (),
                                     range.clone(),
                                     crate::GetSizeMode::Default,
+                                    SimpleReporter::default(),
                                 )
                                 .await
                                 .unwrap();
@@ -238,6 +283,7 @@ mod range {
             mod start_at_0 {
                 use std::sync::Arc;
 
+                use crate::reporter::SimpleReporter;
                 use crate::{config::Config, test_utils::create_test_data, test_utils::*, Condow};
 
                 #[tokio::test]
@@ -272,6 +318,7 @@ mod range {
                                             (),
                                             range,
                                             crate::GetSizeMode::Default,
+                                            SimpleReporter::default(),
                                         )
                                         .await
                                         .unwrap();
@@ -318,6 +365,7 @@ mod range {
                                             (),
                                             range,
                                             crate::GetSizeMode::Default,
+                                            SimpleReporter::default(),
                                         )
                                         .await
                                         .unwrap();
@@ -336,6 +384,7 @@ mod range {
             mod start_after_0 {
                 use std::sync::Arc;
 
+                use crate::reporter::SimpleReporter;
                 use crate::{config::Config, test_utils::create_test_data, test_utils::*, Condow};
 
                 #[tokio::test]
@@ -372,6 +421,7 @@ mod range {
                                                 (),
                                                 range,
                                                 crate::GetSizeMode::Default,
+                                                SimpleReporter::default(),
                                             )
                                             .await
                                             .unwrap();
@@ -421,6 +471,7 @@ mod range {
                                                 (),
                                                 range,
                                                 crate::GetSizeMode::Default,
+                                                SimpleReporter::default(),
                                             )
                                             .await
                                             .unwrap();
